#
# spec file for package sd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sd
Version:        1.0.0+g0
Release:        2.3
Summary:        Intuitive find & replace CLI
URL:            https://github.com/chmln/sd
License:        (Apache-2.0 OR MIT) AND (MIT OR Unlicense) AND BSD-3-Clause AND MIT AND (MIT OR Unlicense)
Group:          System/Base
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  zstd

%description
sd uses regex syntax that you already know from JavaScript and Python.
Forget about dealing with quirks of sed or awk - get productive immediately.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%package        bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%prep
%autosetup -a1

%build
%{cargo_build}

%install
%{cargo_install}

# Zsh completion
install -Dpm644 -T gen/completions/_sd %{buildroot}%{_datadir}/zsh/site-functions/_sd

# Fish completion
install -Dpm644 -T gen/completions/sd.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/sd.fish

# Bash completion
install -Dpm644 -T gen/completions/sd.bash %{buildroot}%{_datadir}/bash-completion/completions/sd

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/sd

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Thu Feb  8 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Cleanup install section. No need to use mkdir when `-T` flag exists.
* Tue Feb  6 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.0.0+g0:
  * Prepare 1.0.0 release (#277)
  * Update `sd` version in lockfile (#275)
  * Prepare 1.0.0-beta.0 release (#274)
  * Remove outdated release checklist step (#272)
  * Fix release checklist indentation (#271)
  * Make modified text blue instead of green (#269)
  * Rework the replacements flag (#267)
  * Temporarily remove recursive (`-r`) flag (#266)
  * Update the changelog (#264)
  * Update `--preview` help text (#263)
- Update specfile
  * add zsh, fish and bash completions
  * remove cargo_config because of new obs-service-cargo
    including that file now to vendored tarball.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Tue Feb 14 2023 socvirnyl.estela@gmail.com
- Automatic update of vendored dependencies.
- Use zstd compressed tarballs.
* Tue Dec 13 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.7.6+g33:
  * Nitpick: a flag can start with `-` too
  * Doc: nitpick `--` has no special meaning to shells
  * Fix paths to release binary in "publish" action
  * Fix recursive preview (show file path)
  * Fix test for replace_into_stdout, since color was added
  * Fix #94: Do not replace symlink with output file
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Wed May  4 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- update LICENSE string
* Wed May  4 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for sd (0.7.6)
